from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String

Fastaxsort_V0_1_0 = CommandToolBuilder(tool="fastaxsort", base_command=["fastaxsort"], inputs=[ToolInput(tag="in_tax_id_mode", input_type=Boolean(optional=True), prefix="--tax-id-mode", doc=InputDocumentation(doc="NCBI Taxonomic data in sequence records are IDs, not names.")), ToolInput(tag="in_indent_i_fier", input_type=Boolean(optional=True), prefix="--indentifier", doc=InputDocumentation(doc="Taxa are sorted using sequence identifiers (default uses whole\ndescriptions)")), ToolInput(tag="in_field", input_type=Boolean(optional=True), prefix="--field", doc=InputDocumentation(doc="Sort sequence records by values at a specific field in sequence\ndescriptions or identifiers. With this option, the description\nor identifier is split into fields using strings of white space\nas field delimiters (the default Perl delimiter for splitting\nlines of data into fields, which are invalid characters in\nsequence identfiers).\nThis option takes a mandatory integer option argument giving the\nindex for which field to sort by. One-based indexing is used, so\nthe first field after the sequence identifier has index 1. As\nstandard in Perl, negative indices count backwards from the last\nfield; field '-1' is the last field, '-2' is the second-to-last\netc. Sequence records for which the specified field does not\nexist will sort on a null key.")), ToolInput(tag="in_split_on_regex", input_type=Boolean(optional=True), prefix="--split-on-regex", doc=InputDocumentation(doc="Use regex <regex> to split descriptions/identifiers for the -f\noption instead of the perl default (which splits on one or more\nwhitespace characters). Special characters must be quoted to\nprotect them from the shell.")), ToolInput(tag="in_annotate", input_type=Boolean(optional=True), prefix="--annotate", doc=InputDocumentation(doc="Add FAST taxonomic addresses in dot-hex notation to sequence\nrecord descriptions")), ToolInput(tag="in_use_append_addresses", input_type=Boolean(optional=True), prefix="-j", doc=InputDocumentation(doc="[string] --join=[strong]\nUse [string] to append FAST taxonomic addresses to sequence\nrecord descriptions, instead of default ' '. Use '\t' to\nindicate a tab-character.")), ToolInput(tag="in_index", input_type=String(optional=True), prefix="--index", doc=InputDocumentation(doc="of printing the sorted sequence records, print a key\nthat maps fastaxsort taxonomically generated taxonomic addresses\nin dot-hexadecimal notation to NCBI taxonomic names or IDs.")), ToolInput(tag="in_man", input_type=Boolean(optional=True), prefix="--man", doc=InputDocumentation(doc="Print the manual page and exit.")), ToolInput(tag="in_log", input_type=Boolean(optional=True), prefix="--log", doc=InputDocumentation(doc="Creates, or appends to, a generic FAST logfile in the current\nworking directory. The logfile records date/time of execution,\nfull command with options and arguments, and an optional\ncomment.")), ToolInput(tag="in_use_name_default", input_type=Boolean(optional=True), prefix="-L", doc=InputDocumentation(doc="[string], --logname=[string]\nUse [string] as the name of the logfile. Default is\n'FAST.log.txt'.")), ToolInput(tag="in_include_comment_logfile", input_type=Boolean(optional=True), prefix="-C", doc=InputDocumentation(doc="[string], --comment=[string]\nInclude comment [string] in logfile. No comment is saved by\ndefault.")), ToolInput(tag="in_format", input_type=Boolean(optional=True), prefix="--format", doc=InputDocumentation(doc="=[format]\nUse alternative format for input. See man page for 'fasconvert'\nfor allowed formats. This is for convenience; the FAST tools are\ndesigned to exchange data in Fasta format, and 'fasta' is the\ndefault format for this tool.")), ToolInput(tag="in_specify_type_sequence", input_type=Boolean(optional=True), prefix="-m", doc=InputDocumentation(doc="[dna|rna|protein], --moltype=[dna|rna|protein]\nSpecify the type of sequence on input (should not be needed in\nmost cases, but sometimes Bioperl cannot guess and complains\nwhen processing data).")), ToolInput(tag="in_fast_q", input_type=Boolean(optional=True), prefix="--fastq", doc=InputDocumentation(doc="Use fastq format as input and output.\n"))], outputs=[], container="quay.io/biocontainers/perl-fast:1.06--pl526_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Fastaxsort_V0_1_0().translate("wdl")

